translate.convert.html2po

Package translate :: Package convert :: Module html2po |
[hide private]
[frames] | no frames]

# Module html2po

source code

convert HTML files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/html2po for examples and usage instructions

Classes | [hide private]
| html2po

Functions | [hide private]
converthtml(inputfile, outputfile, templates, includeuntagged=False, pot=False, duplicatestyle="msgctxt", keepcomments=False) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, html